/**
 * Created by AlgoOy on 9/17/2022.
 */

#ifndef STM32_F1_BSP_LED_H
#define STM32_F1_BSP_LED_H

#include "stm32f1xx.h"

/* 引脚定义 */
#define LED1_PIN                GPIO_PIN_0
#define LED1_GPIO_PORT          GPIOB
#define LED1_GPIO_CLK_ENABLE()  __HAL_RCC_GPIOB_CLK_ENABLE()

#define LED2_PIN                GPIO_PIN_7
#define LED2_GPIO_PORT          GPIOF
#define LED2_GPIO_CLK_ENABLE()  __HAL_RCC_GPIOF_CLK_ENABLE()

#define LED3_PIN                GPIO_PIN_8
#define LED3_GPIO_PORT          GPIOF
#define LED3_GPIO_CLK_ENABLE()  __HAL_RCC_GPIOF_CLK_ENABLE()

/**
 * 控制LED灯亮灭的宏
 * LED低电平亮，设置ON=0，OFF=1
 * 若LED高电平亮，把宏设置成ON=1，OFF=0即可
 */
#define ON  GPIO_PIN_RESET   // GPIO_PIN_RESET 清除端口PIN，低电平
#define OFF GPIO_PIN_SET    // GPIO_PIN_SET 高电平

/* 带参宏 */
#define LED1(a) HAL_GPIO_WritePin(LED1_GPIO_PORT,LED1_PIN,a)
#define LED2(a) HAL_GPIO_WritePin(LED2_GPIO_PORT,LED2_PIN,a)
#define LED3(a) HAL_GPIO_WritePin(LED3_GPIO_PORT,LED3_PIN,a)

/* 直接操作寄存器来控制IO */
#define digitalHi(p, i)     {p->BSRR = i;}                  // 输出高电平
#define digitalLo(p, i)     {p->BSRR = (uint32_t)i << 16;}  // 输出低电平
#define digitalToggle(p, i) {p->ODR ^= i;}                  // 输出反转状态

/* 定义控制IO的宏 */
#define LED1_TOGGLE digitalToggle(LED1_GPIO_PORT,LED1_PIN)
#define LED1_OFF    digitalHi(LED1_GPIO_PORT,LED1_PIN)
#define LED1_ON     digitalLo(LED1_GPIO_PORT,LED1_PIN)

#define LED2_TOGGLE digitalToggle(LED2_GPIO_PORT,LED2_PIN)
#define LED2_OFF    digitalHi(LED2_GPIO_PORT,LED2_PIN)
#define LED2_ON     digitalLo(LED2_GPIO_PORT,LED2_PIN)

#define LED3_TOGGLE digitalToggle(LED3_GPIO_PORT,LED3_PIN)
#define LED3_OFF    digitalHi(LED3_GPIO_PORT,LED3_PIN)
#define LED3_ON     digitalLo(LED3_GPIO_PORT,LED3_PIN)

/* 关闭所有LED */
#define LED_OFF \
                LED1_OFF;\
                LED2_OFF;\
                LED3_OFF;

void LED_GPIO_Config(void);

#endif //STM32_F1_BSP_LED_H